<?php
/*
 * DEFAULT CONFIG SETTINGS
 * 
 * Do not change this file. For custom settings use the config_custom.php
 * and override wanted keys.
 * 
 */
return [

    // ----------------------------------------------------------------------    

    'workDir' => '/var/imldeployment',
    'tmpDir' => '/var/tmp/imldeployment',

    // ----------------------------------------------------------------------    

    'phases' => [
        "preview" => [
            'css' => [
                'bgdark' => 'background:#ccc;',
                'bglight' => 'background:#eee; color:#333;',
                'bgbutton' => 'background:#888; color:#fcfcfc; border: 1px solid rgba(0,0,0,0.15);',
            ],
        ],
        "stage" => [
            'css' => [
                'bgdark' => 'background:#c0c8e0; ',
                'bglight' => 'background:#e0e8f0; color:#333;',
                'bgbutton' => 'background:#78a; color:#fcfcfc; border: 1px solid rgba(0,0,0,0.15);',
            ],
        ],
        "live" => [
            'css_' => [
                'bgdark' => 'background:#c0e0c8;',
                'bglight' => 'background:#e0f0e8; color:#333;',
                'bgbutton' => 'background:#7a8; color:#fcfcfc; border: 1px solid rgba(0,0,0,0.15);',
            ],
            'css' => [
                'bgdark' => 'background:#286; color:#f8f8f8;',
                'bglight' => 'background:#f4f8f0; color:#333; background:rgba(190,220,190,0.5); ',
                'bgbutton' => 'background:#286; color:#fcfcfc; border: 1px solid rgba(0,0,0,0.15);',
            ],
            // prevent immediate installation after build or accept
            "deploytimes" => ['/(Mon|Tue|Wed|Thu)\ 14\:/'],
        ],
    ],
    /*
    'phases_bak' => [
        "preview" => [
            'css' => [
                'bgdark' => 'background:#445;  color:#f8f8f8;',
                'bglight' => 'background:#eee; color:#333; background:rgba(210,210,210,0.4); ',
                'bgbutton' => 'background:#445; color:#fcfcfc; border: 1px solid rgba(0,0,0,0.15);',
            ],
        ],
        "stage" => [
            'css' => [
                'bgdark' => 'background:#336; color:#f8f8f8;',
                'bglight' => 'background:#f0f4f8; color:#333; background:rgba(200,200,220,0.5); ',
                'bgbutton' => 'background:#336; color:#fcfcfc; border: 1px solid rgba(0,0,0,0.15);',
            ],
        ],
        "live" => [
            'css' => [
                'bgdark' => 'background:#286; color:#f8f8f8;',
                'bglight' => 'background:#f4f8f0; color:#333; background:rgba(190,220,190,0.5); ',
                'bgbutton' => 'background:#286; color:#fcfcfc; border: 1px solid rgba(0,0,0,0.15);',
            ],
            // prevent immediate installation after build or accept
            "deploytimes" => ['/(Mon|Tue|Wed|Thu)\ 14\:/'],
        ],
    ],
    */

    'auth' => [
        // force using a given user ... for development only
        'forceuser' => false,

        // use a real login
        'ldap' => [
            'server'       => 'ldaps://ldap.example.com',
            'port'         => 636,
            'DnLdapUser' => 'cn=lookupuser,dc=department,dc=example.com',
            'PwLdapUser' => 'lookupuser_password_here',
            'DnUserNode'   => 'ou=People,dc=department,dc=example.com',
            'DnAppNode'    => 'cn=CI Web-GUI Users,ou=Application Access,dc=department,dc=example.com',
            'debugLevel'   => 0,
        ]
    ],

    'lang' => 'en-en', // for available languages see ./config/lang/*.json

    'showdebug' => [
        'ip'=> ['127.0.0.1'],
    ],
    'projectgroups' => [],
    'banner' => '',
    
    // ----------------------------------------------------------------------
    // build settings
    // ----------------------------------------------------------------------
    'versionsToKeep' => 10, // for cleanup: keep n unused versions
    'builtsToKeep' => 3,
    'build' => [
        'env' => 'export RVMSCRIPT="/usr/local/rvm/scripts/rvm";',
        'hooks' => [
            'build-postclone' => 'hooks/onbuild-postclone',
            'build-precompress' => 'hooks/onbuild',
        ],
    ],

    // ----------------------------------------------------------------------
    // sync of archives
    // ----------------------------------------------------------------------
    'mirrorPackages' => [
        /*

        // (1)
        // sync to a puppet master puppet to extract archive and generate templates
        'puppet' => [
            'type' => 'rsync',
            'runas' => '', // www-data, // nur fuer commandline
            'target' => 'copy-deployment@puppetmaster.example.com:/share/ciserver',
        ],

        // (2)
        // sync to a software package server like https://os-docs.iml.unibe.ch/ci-pkg/
        'package-server' => [
            'type' => 'rsync',
            'runas' => '', // apache httpd user is default, e.g. www-data
            'target' => 'copy-deployment@software.example.com:/var/www/data-ciserver',
        ],
        */
    ],

    // ----------------------------------------------------------------------    
    // plugins
    // existing subkeys = enabled plugins
    // ----------------------------------------------------------------------    
    'plugins'=>[
        'build'=>[
            'tgz'=>[],
            'zip'=>[],
        ],
        'rollout'=>[
            'default'=>[
                'plugin'=>'default',
            ],
            /*
            'ssh'=>[
                'plugin'=>'ssh',
                'user'=>'deployment',
                'privatekey'=>'',
                'addkeycommand'=>'/usr/bin/ssh-keygen -R %s; /usr/bin/ssh-keyscan -t rsa %s >> /home/www-data/.ssh/known_hosts',
                'testcommand'=>'sudo puppet --version',
                'command'=>'/usr/local/bin/puppetrun.sh',
            ],
            'awx'=>[
                'plugin'=>'awx',
                'label'=>'AWX - awx.example.com',
                'url'=>'https://awx.example.com/api/v2', // no ending "/"
                'user'=>'ciserver',
                'password'=>'ciserver',
                'jobtemplate'=>'36',
                'tags'=>'rollout',
            ],
            */
        ],

        // new WIP plugin class: a plugin must have key "enabled"
        'shellcmd'=>[
            'load'=>[
                'enabled'=>1,
            ],
            'processes'=>[
                'enabled'=>1,
            ],
            'top'=>[
                'enabled'=>1,
            ],
        ],
    ],
    
    // ----------------------------------------------------------------------    
    // notifications to messengers ...
    // ----------------------------------------------------------------------    
    'messenger'=>[
        'slack'=>[
            'presets'=>[],
        ],
        'email'=>[
            'from'=>'noreply@ciserver.example.com',
        ]
    ],

    // ----------------------------------------------------------------------    
    // TODO: functionality to be removed?!
    // ----------------------------------------------------------------------    

    'foreman__' => [
        'api'=>'https://foreman.example.com/', // with ending "/"
        'user'=>'ci-server',
        'password'=>'ciserver_password_here',
        'ignore-ssl-error'=>true,
        // 'varname-replace'=>'ci-replacement',
    ],

    // where to store project data
    'projects' => [
        'json' => [
            'active'       => true,
        ],
        'ldap' => [
            'active'       => false,
        ],
    ],
    // ----------------------------------------------------------------------    

];